@@ -157,10 +157,12 @@ fn generate_handler(args: HandlerArgs, input: TokenStream) -> Result<TokenStream
 
         #[#crate_name::async_trait]
         impl #crate_name::Endpoint for #ident {
+            type Output = #crate_name::Response;
+
             #guard
 
-            async fn call(&self, mut req: #crate_name::Request) -> #crate_name::Response {
-                let (req, mut body) = req.split_body();
+            async fn call(&self, mut req: #crate_name::Request) -> Self::Output {
+                let (req, mut body) = req.split();
                 #(#extractors)*
                 #item_fn
                 #crate_name::IntoResponse::into_response(#ident(#(#args),*)#call_await)
